4-Class motor imagery (Arrows) — BCI-Framework documentation

# 4-Class motor imagery (Arrows)

Implemented through extensions systems in the FourClassMotorImagery module.

This cue-based BCI paradigm consisted of up to four different motor imagery tasks, represented by a succession of cues (arrow-shaped) and separated with an asynchronous break. This paradigm used an arrow pointing to the left right, up or bottom, which has been widely used 1 2.

## Configuration options

Cues:
Is possible to select up to 4 classes, represented by one arrow. All 4 classes are active by default.
Trials per class:
How many trials per class will contain the run. Between 1 and 100, 10 by default.
Stimulus duration:
The time in milliseconds that will display the cue on screen. Between 2000 and 6000 ms, 4000 by default
Stimulus onset asynchronously:
To prevent fixed time between trials. A range between 1000 and 3000 ms, (2000-3000) by default. This means that for each trial a random number (with uniform distribution) is generated between this range and used as inter stimulus interval.

### References

1

  Kyuwan Choi. Electroencephalography (eeg)-based neurofeedback training for brain–computer interface (bci). Experimental brain research, 231(3):351–365, 2013.

2

  Catalina Llanos, Manuel Rodriguez, Clara Rodriguez-Sabate, Ingrid Morales, and Magdalena Sabate. Mu-rhythm changes during the planning of motor and motor imagery actions. Neuropsychologia, 51(6):1019–1026, 2013.